import { readImageDicomFileSeries } from "@itk-wasm/dicom";
import vtkITKHelper from "@kitware/vtk.js/Common/DataModel/ITKHelper";
import vtkVolume from "@kitware/vtk.js/Rendering/Core/Volume";
import vtkFullScreenRenderWindow from "@kitware/vtk.js/Rendering/Misc/FullScreenRenderWindow";
import "@kitware/vtk.js/Rendering/Profiles/Volume";
import vtkActor from "@kitware/vtk.js/Rendering/Core/Actor";
import { useEffect, useRef, useState } from "react";
import vtkRenderer from "@kitware/vtk.js/Rendering/Core/Renderer";
import vtkVolumeMapper from "@kitware/vtk.js/Rendering/Core/VolumeMapper";

function App() {
  const [files, setFiles] = useState<File[]>([]);
  const rendererRef = useRef<vtkRenderer>();
  const mapperRef = useRef();
  const actorRef = useRef();
  const renderWindowRef = useRef();

  useEffect(() => {
    if (files.length > 0) {
      const fullScreenRenderer = vtkFullScreenRenderWindow.newInstance({});
      rendererRef.current = fullScreenRenderer.getRenderer();
      renderWindowRef.current = fullScreenRenderer.getRenderWindow();
      actorRef.current = vtkVolume.newInstance();
      mapperRef.current = vtkVolumeMapper.newInstance({ sampleDistance: 1.1});

      readImageDicomFileSeries(null, {
        inputImages: files,
      }).then((image) => {
        const vtkImage = vtkITKHelper.convertItkToVtkImage(image.outputImage);

        mapperRef.current.setInputData(vtkImage);
        actorRef.current.setMapper(mapperRef.current);

        rendererRef.current?.addVolume(actorRef.current)
        rendererRef.current.resetCamera();
        renderWindowRef.current.render();
      });
    }
  }, [files]);

  const handleFolderUpload = async (event: Event) => {
    const target = event.target as HTMLInputElement;
    if (!target.files) return;
    const files = [...target.files].filter((file) =>
      file.name.endsWith(".dcm")
    );
    setFiles(files);
  };

  return (
    <>
      <input
        type="file"
        onChange={handleFolderUpload}
        webkitdirectory="true"
        style={{ position: "fixed", zIndex: 100 }}
      />
    </>
  );
}

export default App;
